@@ -698,6 +698,11 @@ def bootstrap_pagination(page, **kwargs):
 
             :default: ``None``
 
+        extra_classes
+            Appends string as extra CSS classes to the pagination ul.
+
+            :default: ``None``
+
         extra
             Any extra page parameters.
 
@@ -733,6 +738,7 @@ def get_pagination_context(
     url=None,
     size=None,
     justify_content=None,
+    extra_classes=None,
     extra=None,
     parameter_name="page",
 ):
@@ -800,6 +806,9 @@ def get_pagination_context(
                 " Valid values are 'start', 'center', 'end'."
             )
 
+    if extra_classes:
+        pagination_css_classes.append(extra_classes)
+
     return {
         "bootstrap_pagination_url": url,
         "num_pages": num_pages,
