@@ -147,3 +147,60 @@ class BootstrapFieldSelectTestCase(BootstrapTestCase):
                 "</div>"
             ),
         )
+
+    def test_select_size_sm(self):
+        """Test field with select widget with size='sm'."""
+        self.assertHTMLEqual(
+            self.render('{% bootstrap_field form.test size="sm" %}', context={"form": SelectTestForm()}),
+            (
+                '<div class="django_bootstrap5-req mb-3">'
+                '<label class="form-label">Test</label>'
+                '<div id="id_test" class="btn-group" role="group">'
+                '<input type="radio" class=" btn-check" autocomplete="off" name="test" id="id_test_0" value="1" '
+                "required>"
+                '<label class="btn btn-outline-primary btn-sm" for="id_test_0">one</label>'
+                '<input type="radio" class=" btn-check" autocomplete="off" name="test" id="id_test_1" value="2" '
+                "required>"
+                '<label class="btn btn-outline-primary btn-sm" for="id_test_1">two</label>'
+                "</div>"
+                "</div>"
+            ),
+        )
+
+    def test_select_size_lg(self):
+        """Test field with select widget with size='lg'."""
+        self.assertHTMLEqual(
+            self.render('{% bootstrap_field form.test size="lg" %}', context={"form": SelectTestForm()}),
+            (
+                '<div class="django_bootstrap5-req mb-3">'
+                '<label class="form-label">Test</label>'
+                '<div id="id_test" class="btn-group" role="group">'
+                '<input type="radio" class=" btn-check" autocomplete="off" name="test" id="id_test_0" value="1" '
+                "required>"
+                '<label class="btn btn-outline-primary btn-lg" for="id_test_0">one</label>'
+                '<input type="radio" class=" btn-check" autocomplete="off" name="test" id="id_test_1" value="2" '
+                "required>"
+                '<label class="btn btn-outline-primary btn-lg" for="id_test_1">two</label>'
+                "</div>"
+                "</div>"
+            ),
+        )
+
+    def test_select_size_md(self):
+        """Test field with select widget with size='md' (default, no extra class)."""
+        self.assertHTMLEqual(
+            self.render('{% bootstrap_field form.test size="md" %}', context={"form": SelectTestForm()}),
+            (
+                '<div class="django_bootstrap5-req mb-3">'
+                '<label class="form-label">Test</label>'
+                '<div id="id_test" class="btn-group" role="group">'
+                '<input type="radio" class=" btn-check" autocomplete="off" name="test" id="id_test_0" value="1" '
+                "required>"
+                '<label class="btn btn-outline-primary" for="id_test_0">one</label>'
+                '<input type="radio" class=" btn-check" autocomplete="off" name="test" id="id_test_1" value="2" '
+                "required>"
+                '<label class="btn btn-outline-primary" for="id_test_1">two</label>'
+                "</div>"
+                "</div>"
+            ),
+        )
